<?php
/**
* @package      EasySocial
* @copyright    Copyright (C) 2010 - 2017 Stack Ideas Sdn Bhd. All rights reserved.
* @license      GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

jimport('joomla.filesystem.file');

$file = JPATH_ADMINISTRATOR . '/components/com_easysocial/includes/plugins.php';

if (!JFile::exists($file)) {
	return;
}

require_once($file);
require_once(JPATH_ADMINISTRATOR . '/components/com_hikashop/helpers/helper.php');

class PlgHikashopEasySocial extends EasySocialPlugins
{
	public $group = 'hikashop';
	public $element = 'easysocial';
	protected $autoloadLanguage = true;

	/**
	 * Retrieves the plugin params
	 *
	 * @since	2.0
	 * @access	public
	 */
	public function getPluginParams()
	{
		static $tmp = false;

		if(!$tmp) {
			$plugin	= JPluginHelper::getPlugin('hikashop' , 'easysocial');
			$tmp = ES::registry($plugin->params);
		}

		return $tmp;
	}

	/**
	 * Assign points to author when they create a new product in Hikashop
	 *
	 * @since	2.0
	 * @access	public
	 */
	public function onAfterProductCreate(&$product)
	{
		$params = $this->getPluginParams();
		$appParams = $this->getAppParams('hikashop', SOCIAL_TYPE_USER);

		// Since hikashop doesn't have created_by, we get the current logged in user
		$user = ES::user();

		$component = $this->input->get('option', '', 'string');

		// @stream: create
		// Create stream if necessary
		if ($component != 'com_easysocial' && $appParams->get('stream_create', true) && $product->product_published == "1") {
			$this->createStream($product, 'create', $user->id);
		}

	}

	/**
     * After order confirmed
     *
     * @since   2.0
     * @access  public
     * @param   string
     * @return
     */
	public function onAfterOrderCreate(&$order, &$send_email)
	{
		$params = $this->getPluginParams();
		$appParams = $this->getAppParams('hikashop', SOCIAL_TYPE_USER);

		// Since hikashop doesn't have created_by, we get the current logged in user
		$user = ES::user();

		// @stream: create
		// Create stream if necessary
		if ($appParams->get('stream_order', true) && $order->order_status == 'created' && $order->order_type == 'sale') {
			$this->orderStream($order, 'order', $user->id);
		}
	}

	/**
	 * Perform cleanup when an article is being deleted
	 *
	 * @since	2.0
	 * @access	public
	 */
	public function onContentBeforeDelete($context, $data)
	{
		if ($context != 'com_content.article') {
			return;
		}

		// Delete the items from the stream.
		$stream = ES::stream();
		$stream->delete($data->id, 'article');
	}

	/**
	 * Generate new stream activity.
	 *
	 * @since	2.0
	 * @access	public
	 * @param	string
	 * @return
	 */
	private function orderStream($order , $verb, $actor = null)
	{
		$tmpl = ES::stream()->getTemplate();

		if(is_null($actor)) {
			$actor = ES::user()->id;
		}

		//check if this user already perform the same action or not.
		$stream = ES::stream();

		if ($stream->exists($order->order_id, 'hikashop', $verb, $actor)) {
			return;
		}

		// Set the creator of this order.
		$tmpl->setActor($actor, SOCIAL_TYPE_USER);

		// Set the context of the stream item.
		$tmpl->setContext($order->order_id, 'hikashop');

		// Set the verb
		$tmpl->setVerb($verb);

		// // Get the permalink
		// $permalink	= hikashop_contentLink('product&task=show&cid='.$product->product_id.'&name='.$product->product_alias, $product);

		// Store the product in the params
		$registry 	= ES::registry();
		$registry->set('order' , $order);
		// $registry->set('permalink', $permalink);

		// We need to tell the stream that this uses the core.view privacy.
		$tmpl->setAccess('core.view');

		// Set the template params
		$tmpl->setParams($registry);

		ES::stream()->add($tmpl);
	}

	/**
	 * Generate new stream activity.
	 *
	 * @since	2.0
	 * @access	public
	 * @param	string
	 * @return
	 */
	private function createStream($product , $verb, $actor = null)
	{
		$tmpl = ES::stream()->getTemplate();

		if(is_null($actor)) {
			$actor = ES::user()->id;
		}

		//check if this user already perform the same action or not.
		$stream = ES::stream();
		if ($stream->exists($product->product_id, 'hikashop', $verb, $actor)) {
			return;
		}

		// Set the creator of this product.
		$tmpl->setActor($actor, SOCIAL_TYPE_USER);

		// Set the context of the stream item.
		$tmpl->setContext($product->product_id, 'hikashop');

		// Set the verb
		$tmpl->setVerb($verb);

		// Get the permalink
		$permalink	= hikashop_contentLink('product&task=show&cid='.$product->product_id.'&name='.$product->product_alias, $product);

		// Store the product in the params
		$registry 	= ES::registry();
		$registry->set('product' , $product);
		$registry->set('permalink', $permalink);

		// We need to tell the stream that this uses the core.view privacy.
		$tmpl->setAccess('core.view');

		// Set the template params
		$tmpl->setParams($registry);

		ES::stream()->add($tmpl);
	}
}
